import { CSSProperties } from '@material-ui/core/styles/withStyles';
import { ReactNode } from 'react';
import { TooltipAnchorProps } from '../Tooltip';
export type OnClickCallback = (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
export type ButtonVariant = 'primary' | 'secondary' | 'success' | 'danger' | 'warning';
export interface ButtonProps extends TooltipAnchorProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * On click handler of button.
     */
    onClick?: OnClickCallback;
    /**
     * Defines if the button has a background fill or is a flat button without fill.
     * @default default
     */
    shape?: 'default' | 'flat';
    /**
     * Defines the color variant of the button.
     * @default primary
     */
    variant?: ButtonVariant;
    /**
     * Defines the size of the button.
     * @default m
     */
    size?: 's' | 'm' | 'l';
    /**
     * Specifies the slot left for the button.
     * Property meant for adding icons to the buttons.
     * `Use encouraged`
     */
    slotLeft?: JSX.Element;
    /**
     * Specifies the slot right for the button.
     * Property meant for adding icons to the buttons.
     * `Use encouraged`
     */
    slotRight?: JSX.Element;
    /**
     * Passing an icon with this prop will make the button an icon only buton without text.
     */
    iconOnly?: JSX.Element;
    /**
     * Specifies the type of button.
     * For type `reset` and `submit` use `SubmitButton` and `ResetButton` when used within a formik form.
     * @default button
     */
    type?: 'button' | 'reset' | 'submit';
    /**
     * Also show the tooltip when the button is not disabled.
     * @default false
     */
    alwaysShowTooltip?: boolean;
    /**
     * Makes the button disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Sets the button to fill horizontal space.
     * @default false
     */
    wide?: boolean;
    /**
     * Displays spinner in button.
     * Note: button is disabled while loading.
     * @default false
     */
    loading?: boolean;
    /**
     * Specifies inverse button when it's placed on a dark background.
     * Currently only implemented for `variant='flat'` buttons.
     * @default false
     */
    inverse?: boolean;
    /**
     * Sets styles for a toggled button.
     * Toggled prop should be used alongside the `variant='secondary` and `shape='default'`.
     * @default false
     */
    toggled?: boolean;
    /**
     * Specifies the margin top.
     */
    mt?: CSSProperties['marginTop'];
    /**
     * Specifies the margin right.
     */
    mr?: CSSProperties['marginRight'];
    /**
     * Specifies the margin bottom.
     */
    mb?: CSSProperties['marginBottom'];
    /**
     * Specifies the margin left.
     */
    ml?: CSSProperties['marginLeft'];
    /**
     * Specifies the id.
     */
    id?: string;
    /**
     * Button content
     */
    children?: ReactNode;
}
/**
 * Generic button component.
 * For more specific use-cases consider using `ActionButton`, `Tag`, `ListItem`, `SubmitButton` or `ResetButton`.

  ### Import

  ```
  import Button from '@impargo/components/Button'
  ```
 */
export declare const Button: import("@emotion/styled").StyledComponent<ButtonProps & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default Button;
//# sourceMappingURL=index.d.ts.map