import { CSSProperties, MouseEventHandler } from 'react';
export type Orientation = 'vertical' | 'horizontal';
export type Type = 'default' | 'readable';
export interface ListItemProps extends React.HTMLAttributes<HTMLLIElement> {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Sets secondary label in the list item.
     */
    label?: string | JSX.Element;
    /**
     * Specifies left slot of the list item.
     */
    slotLeft?: string | JSX.Element;
    /**
     * Specifies right slot of the list item.
     */
    slotRight?: string | JSX.Element;
    /**
     * Specifies the function that will be applied when list item is clicked.
     * Note: if prop not passed the item will not be clickable.
     */
    onClick?: MouseEventHandler;
    /**
     * Specifies if the list item should have a border bottom.
     * @default true
     */
    hasBorder?: boolean;
    /**
     * Add truncated style to the label.
     * @default false
     */
    truncated?: boolean;
    /**
     * Specifies the white space property for the label.
     */
    whiteSpace?: CSSProperties['whiteSpace'];
    /**
     * Add disabled styles to the component and disables the onClick prop. Also used for data display without an onClick handler.
     * @default false
     */
    disabled?: boolean;
    /**
     * Disables the `onClick` function on the list item.
     * This prop is similar to disabled prop but the label text has no disabled styles.
     * For the label to have disabled styles, add a `Text` component inside the label and pass a `disabled` prop to the `Text` component.
     * This prop should be used instead of `disabled` prop when a tooltip should be shown in a disabled list item.
     */
    notAllowed?: boolean;
    /**
     * Specifies if the list item is active or not. Active items are used for navigation.
     * @default false
     */
    isActive?: boolean;
    /**
     * Specifies if the list item is selected via checkbox, also gives a different background to selected items.
     * Note: If `isActive` and `unread` are also set, the styling of `isSelected` will have priority over the others.
     * @default false
     */
    isSelected?: boolean;
    /**
     * Specifies if the list item has been read or not.
     * @default false
     */
    unread?: boolean;
    /**
     * Specifies padding left and right.
     */
    px?: CSSProperties['paddingRight'];
    /**
     * Specifies padding top and bottom.
     */
    py?: CSSProperties['paddingTop'];
    /**
     * Html element to be displayed.
     * @default li
     */
    as?: React.ElementType;
    /**
     * Specifies left slot vertical alignment.
     * Takes `align-self` flex item property values.
     * @default center
     */
    slotLeftAlign?: CSSProperties['alignSelf'];
    /**
     * Specifies right slot vertical alignment.
     * Takes `align-self` flex item property values.
     * @default center
     */
    slotRightAlign?: CSSProperties['alignSelf'];
    /**
     * Specifies label vertical alignment.
     * Takes `align-items` property values.
     * @default flex-start
     */
    labelAlign?: CSSProperties['alignItems'];
    /**
     * Sets secondary label in the list item.
     */
    secondaryLabel?: string | JSX.Element;
    /**
     * Sets the labes style to a subtitle text.
     * Used to separarte sections inside a list.
     */
    subtitle?: boolean;
    /**
     * Set target of `href` link (e.g. `_blank`).
     */
    target?: string;
    /**
     * Set link href attribute of list item.
     */
    href?: string;
    /**
     * Specifies the orientation of the component.
     * @default horizontal
     */
    orientation?: Orientation;
    /**
     * TODO: Add description.
     * @default true
     */
    closeDropdownOnClick?: boolean;
    /**
     * Specifies the type of component.
     * Use `readable` if the component should have predefined unread styles.
     * @default default
     */
    type?: Type;
    /**
     * Specifies the alignment of the badge component when type `type='readable'` is passed.
     */
    badgeAlign?: CSSProperties['alignSelf'];
}
/**
 * The `ListItem` component is used to display data inside a list, display a nav list with nav items and display a items inside a menu in a dropdown.
 */
export declare const ListItem: import("@emotion/styled").StyledComponent<ListItemProps & import("react").RefAttributes<unknown> & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default ListItem;
//# sourceMappingURL=ListItem.d.ts.map