import { ColumnPinningState } from '@tanstack/react-table';
import { Dispatch, ReactElement, ReactNode, SetStateAction } from 'react';
import { PaginationProps } from './pagination';
import { ColumnType, RenderFunction, Sorting } from './types';
export type { ColumnType, RenderFunction };
export interface TableProps<RowType extends {}> {
    /**
     * Class name assigned to the component. Should be used sparingly.
     * Note: this is applied to the container div, not to the `table` element itself.
     */
    className?: string;
    /**
     * Similar to `customRenderer` but is used for the headers only
     */
    customHeaderRenderer?: {
        [attribute: string]: RenderFunction<RowType> | JSX.Element | string;
    };
    /**
     * Object with keys equal to columns names and the values are functions which are passed the row value.
     * Used to override the default values and render cusotm cells for that column.
     */
    customRenderer?: {
        [attribute: string]: RenderFunction<RowType>;
    };
    /**
     * Activates selectable checkboxes
     * @default false
     */
    selectable?: boolean;
    /**
     * Enables sorting columns in this table.
     */
    sortable?: boolean;
    /**
     * Disables table for interactions (e.g. selecting rows).
     * @default false
     */
    disabled?: boolean;
    /**
     * Array of objects containing the table column names.
     * Each column is either a json object with `name`, `width` and `sortType` attributes, or simply a `string`.
     */
    columns: (string | ColumnType<RowType>)[];
    /**
     * Specifies the ordering of the columns. Can be used to re-arrange the columns without having to change the columns array.
     * You can use the column names (e.g. `column.name`, or `column` if it's a string).
     * @example ['_id', 'status', 'date']
     */
    columnOrder?: string[];
    /**
     * Array containing the rows to display.
     * The table will re-render if the data is changed dynamically, aslong as it's changed in an immutable way.
     */
    data: RowType[];
    /**
     * A function that takes the value of the row as an argument.
     * Returns true if you want to show the row badge.
     */
    showRowBadge?: (row: RowType) => boolean;
    /**
     * A function that has the value of the hovered row as an argument.
     * Called whenever the mouse is hovered over a row.
     * Note, that whenever the mouse exits the row, the function will be called with `null`.
     * Use this as a way to do whatever you like when the mouse is no longer hovering over a row.
     * If this prop is supplied, then a hover styling is also applied to the rows.
     */
    onHoverRow?: (hovered: RowType | null) => void;
    /**
     * A function that has the value of the pressed/clicked row as an argument.
     * If this prop is supplied, then active and focus states styling is also applied to the rows.
     */
    onPressRow?: (row: RowType) => void;
    /**
     * Pagination data. If passed, will show navigation controls at the bottom right side of the table.
     */
    pagination?: PaginationProps['pagination'];
    /**
     * Function used to render the batch action component.
     * When table selectable is set to false, the function should take 0 arguments.
     */
    batch?: (selected: RowType[], clearSelectedRows: () => void) => JSX.Element;
    /**
     * Specifies the loading state of the table, while `true`, will hide the table rows and show a spinner.
     */
    loading?: boolean;
    /**
     * Whether sorting will be handled manually (i.e. server-side sorting).
     * If true, then onSortChange must be supplied and handled properly.
     * Otherwise, sorting will not work.
     */
    manualSortBy?: boolean;
    /**
     * Callback triggered when a column's sorting changes.
     */
    onSortChange?: (sorting: Sorting) => void;
    /**
     * Whether the selected state will be reset if the data array changes.
     * @default false
     */
    autoResetSelectedRows?: boolean;
    /**
     * Specifies the id for testing.
    */
    'data-testid'?: string;
    /**
     * Specifies the initial sorting of the table in the same format as onSortChange parameters.
     * it has this format so as not to confuse it with the same format as onSortChange.
     */
    InitialSorting?: Sorting;
    /**
     * An element that can be shown when the table is empty, maybe as a result of filtering or specific search strings.
     * If the table is empty because no data is created yet, consider instead completely hiding the table and directly using a state component.
     */
    emptyTableMessage?: ReactNode;
    /**
     * Lists of columns to pin `left` and `right`. Pinned columns are sticky and do not scroll horizontally with the other columns.
     */
    columnPinning?: ColumnPinningState;
    /**
     * While the `Table` component can handle the row selection state by itself,
     * it also gives you the option to control the row selection from the parent,
     * using the props `selectedRows` and `onSelectedRowsChanged`.
     *
     * If `selectedRows` is passed, it will override the internal row selection state of the `Table` component.
     */
    selectedRows?: RowType[];
    /**
     * While the `Table` component can handle the row selection state by itself,
     * it also gives you the option to control the row selection from the parent,
     * using the props `selectedRows` and `onSelectedRowsChanged`.
     *
     * If `onSelectedRowsChanged` is passed, it will override the internal row selection state of the `Table` component.
     * Use it to update the parent's state when the row selection changes, when the user selects or unselects a row using the checkboxes.
     */
    onSelectedRowsChanged?: Dispatch<SetStateAction<RowType[]>>;
}
export declare function Table<T extends object>({ columns: keys, columnOrder, customRenderer, customHeaderRenderer, InitialSorting, selectable, data, batch, pagination, loading, onHoverRow, onPressRow, manualSortBy, onSortChange, sortable, showRowBadge, autoResetSelectedRows, emptyTableMessage, columnPinning, selectedRows: selectedRowsProp, onSelectedRowsChanged: onSelectedRowsChangedProp, ...containerProps }: TableProps<T>): ReactElement;
/**
 * @deprecated use named export `Table` instead.
 */
export default Table;
//# sourceMappingURL=index.d.ts.map