import { CSSProperties, ReactNode } from 'react';
import { TooltipAnchorProps } from '../Tooltip';
export type TextOnClickCallback = (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
export interface TextProps extends TooltipAnchorProps {
    /**
     * Class name assigned to the component. Should be used sparingly.
     */
    className?: string;
    /**
     * Additional prop that changes the HTML element that will be displayed.
     * If prop is missing, it will be mapped according to the variant prop.
     * @default p
     */
    el?: string;
    /**
     * Styles the HTML element.
     * @default body
     */
    variant?: 'heading1' | 'heading2' | 'heading3' | 'subtitle' | 'body' | 'small' | 'smallest';
    /**
     * Add truncated style.
     * @default false
     */
    truncated?: boolean;
    /**
     * Applies font-weight of 600.
     * @default false
     */
    bold?: boolean;
    /**
     * Applies the secondary font color.
     * Overwrites the `color` property.
     * @default false
     */
    secondary?: boolean;
    /**
     * Specifies the white space property.
     */
    whiteSpace?: CSSProperties['whiteSpace'];
    /**
     * Specifies the width property.
     */
    width?: CSSProperties['width'];
    /**
     * Add disabled style.
     * @default false
     */
    disabled?: boolean;
    /**
     * Changes the font weight of the rendered text. To set the text bold use the `bold` boolean prop. Use sparingly.
     */
    fontWeight?: CSSProperties['fontWeight'];
    /**
     * CSS font-style property.
     */
    fontStyle?: CSSProperties['fontStyle'];
    /**
     * CSS text-align property.
     */
    textAlign?: CSSProperties['textAlign'];
    /**
     * CSS text-decoration property. Only applied when the `el` prop has a `a` value or when an `onClick` handler is passed.
     */
    textDecoration?: CSSProperties['textDecoration'];
    /**
     * CSS text-align property. Defaults to `theme.baseFontColor`.
     */
    color?: CSSProperties['color'];
    /**
     * Used to make link out of text. Use in combination with `el='a'`.
     */
    href?: string;
    /**
     * Target of link. Use in combination with `href` and `el='a'`.
     */
    target?: string;
    /**
     * The `rel` attribute defines the relationship between a linked resource and the current document. Valid on `<link>`, `<a>`, `<area>`, and `<form>`, the supported values depend on the element on which the attribute is found. More information about the `rel` attribute can be found here: [MDN Web Docs](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/rel).
     */
    rel?: string;
    /**
     * Specifies the line-height property.
     * Note: theme line height variable: `fontLineHeight: 20px`, `fontLineHeightM: 24px`. Use sparingly.
     */
    lineHeight?: CSSProperties['lineHeight'];
    /**
     * Click handler function.
     */
    onClick?: TextOnClickCallback;
    /**
     * The text itself.
     */
    children: ReactNode;
}
/**
 * The `Text` component is used to render text.
 * The font used is `Source Sans Pro`.
 *
 * ### Variant map
 * Depending on the prop `variant` different HTLML elements are rendered:
 *
 *  - heading1: `h1`
 *  - heading2: `h2`
 *  - heading3: `h3`
 *  - subtitle: `h4`
 *  - body: `p`
 *  - small: `p`
 *  - smallest: `p`

  ### Import

  ```
  import Text from '@impargo/components/Text'
  ```
 */
export declare const Text: import("@emotion/styled").StyledComponent<TextProps & import("react").RefAttributes<HTMLElement> & {
    theme?: import("@emotion/react").Theme | undefined;
}, {}, {}>;
export default Text;
//# sourceMappingURL=index.d.ts.map